==> firefox-3.5.10.source.tar.bz2: mozilla-1.9.1/accessible/src/msaa/nsXULMenuAccessibleWrap.cpp <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is IBM Corporation
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Author: Aaron Leventhal (aleventh@us.ibm.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsXULMenuAccessibleWrap.h"
#include "nsAccessibilityAtoms.h"
#include "nsINameSpaceManager.h"

// --------------------------------------------------------
// nsXULMenuAccessibleWrap Accessible
// --------------------------------------------------------

nsXULMenuitemAccessibleWrap::nsXULMenuitemAccessibleWrap(nsIDOMNode *aDOMNode, 
                                                         nsIWeakReference *aShell):
nsXULMenuitemAccessible(aDOMNode, aShell)
{
}

NS_IMETHODIMP
nsXULMenuitemAccessibleWrap::GetName(nsAString& aName)
{
  // XXX This should be done in get_accName() so that nsIAccessible::GetName()]
  // provides the same results on all platforms
  nsresult rv = nsXULMenuitemAccessible::GetName(aName);
  if (NS_FAILED(rv)) {
    return rv;
  }
  nsCOMPtr<nsIContent> content(do_QueryInterface(mDOMNode));
  NS_ASSERTION(content, "Should not have gotten past nsXULMenuitemAccessible::GetName");
  
  nsAutoString accel;
  content->GetAttr(kNameSpaceID_None, nsAccessibilityAtoms::acceltext, accel);
  if (!accel.IsEmpty()) {
    aName += NS_LITERAL_STRING("\t") + accel;
  }

  return NS_OK;
}

==> firefox-4.0.source.tar.bz2: mozilla-2.0/accessible/src/msaa/nsXULMenuAccessibleWrap.cpp <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is IBM Corporation
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Author: Aaron Leventhal (aleventh@us.ibm.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsXULMenuAccessibleWrap.h"
#include "nsAccessibilityAtoms.h"
#include "nsINameSpaceManager.h"

////////////////////////////////////////////////////////////////////////////////
// nsXULMenuAccessibleWrap
////////////////////////////////////////////////////////////////////////////////

nsXULMenuitemAccessibleWrap::
  nsXULMenuitemAccessibleWrap(nsIContent *aContent, nsIWeakReference *aShell) :
  nsXULMenuitemAccessible(aContent, aShell)
{
}

NS_IMETHODIMP
nsXULMenuitemAccessibleWrap::GetName(nsAString& aName)
{
  // XXX This should be done in get_accName() so that nsIAccessible::GetName()]
  // provides the same results on all platforms
  nsresult rv = nsXULMenuitemAccessible::GetName(aName);
  if (NS_FAILED(rv)) {
    return rv;
  }
  
  nsAutoString accel;
  mContent->GetAttr(kNameSpaceID_None, nsAccessibilityAtoms::acceltext, accel);
  if (!accel.IsEmpty()) {
    aName += NS_LITERAL_STRING("\t") + accel;
  }

  return NS_OK;
}
